Spherical-Helmholtz-Translation-and-Rotation
============================================
.. image:: https://github.com/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation/workflows/Tests/badge.svg
    :target: https://github.com/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation/actions?query=workflow%3ATests

.. image:: https://img.shields.io/pypi/v/shetar
    :target: https://pypi.org/project/shetar/

.. image:: https://img.shields.io/github/license/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation
    :target: https://github.com/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation/blob/master/LICENSE

.. image:: https://img.shields.io/github/last-commit/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation/master?label=last%20release
    :target: https://github.com/AppliedAcousticsChalmers/Spherical-Helmholtz-Translation-and-Rotation

Python implementations of translation and rotation theorems for spherical solutions of the Helmholtz equation in three dimensions.
This is heavily based on the book "Fast Multipole Methods for the Helmholtz Equation in Three Dimensions",
by N. A. Gumerov and R. Duraiswami, Elsevier 2005.
